@@ -11,5 +11,5 @@
     col <- ncol(m1)
     isim<-testmantel(nrepet, col, as.matrix(m1), as.matrix(m2))
     obs<-isim[1]
-    return(as.randtest(sim = isim[-1], obs = obs, call = match.call(), ...))
+    return(as.randtest(sim = isim[-1], obs = obs, call = match.call(), subclass = "mantelrtest", ...))
 }
